==> jmc-8.3.0.ga.tar.gz: jmc-8.3.0-ga/application/tests/org.openjdk.jmc.flightrecorder.controlpanel.ui.test/src/test/java/org/openjdk/jmc/flightrecorder/controlpanel/ui/model/test/EventConfigurationTest.java <==
/*
 * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
 * 
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The contents of this file are subject to the terms of either the Universal Permissive License
 * v 1.0 as shown at http://oss.oracle.com/licenses/upl
 *
 * or the following license:
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions
 * and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other materials provided with
 * the distribution.
 * 
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to
 * endorse or promote products derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
 * WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.openjdk.jmc.flightrecorder.controlpanel.ui.model.test;

import static org.openjdk.jmc.flightrecorder.configuration.events.SchemaVersion.V1;
import static org.openjdk.jmc.flightrecorder.configuration.events.SchemaVersion.V2;

import java.io.InputStream;

import org.junit.Test;

import org.openjdk.jmc.flightrecorder.configuration.events.IEventConfiguration;
import org.openjdk.jmc.flightrecorder.configuration.events.SchemaVersion;
import org.openjdk.jmc.flightrecorder.controlpanel.ui.configuration.model.xml.XMLModel;
import org.openjdk.jmc.flightrecorder.controlpanel.ui.model.EventConfiguration;

@SuppressWarnings("nls")
public class EventConfigurationTest {

	private IEventConfiguration loadConfig(String jfcName) throws Exception {
		try (InputStream in = EventConfigurationTest.class.getResourceAsStream(jfcName)) {
			XMLModel model = EventConfiguration.createModel(in);
			return new EventConfiguration(model);
		}
	}

	private void validateConfig(String jfcName, SchemaVersion version) throws Exception {
		try (InputStream in = EventConfigurationTest.class.getResourceAsStream(jfcName)) {
			EventConfiguration.validate(in, jfcName, version);
		}
	}

	@Test
	public void testLoadV1() throws Exception {
		loadConfig("continous_jfr_1_0.jfc");
	}

	@Test
	public void testLoadV2() throws Exception {
		loadConfig("continous_jfr_2_0.jfc");
	}

	@Test
	public void testValidateV1() throws Exception {
		validateConfig("continous_jfr_1_0.jfc", V1);
	}

	@Test
	public void testValidateV2() throws Exception {
		validateConfig("continous_jfr_2_0.jfc", V2);
	}
}

==> jmc-9.1.1.ga.tar.gz: jmc-9.1.1-ga/application/tests/org.openjdk.jmc.flightrecorder.controlpanel.ui.test/src/test/java/org/openjdk/jmc/flightrecorder/controlpanel/ui/model/test/EventConfigurationTest.java <==
/*
 * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
 * 
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The contents of this file are subject to the terms of either the Universal Permissive License
 * v 1.0 as shown at https://oss.oracle.com/licenses/upl
 *
 * or the following license:
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted
 * provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions
 * and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other materials provided with
 * the distribution.
 * 
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to
 * endorse or promote products derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
 * WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.openjdk.jmc.flightrecorder.controlpanel.ui.model.test;

import static org.openjdk.jmc.flightrecorder.configuration.events.SchemaVersion.V1;
import static org.openjdk.jmc.flightrecorder.configuration.events.SchemaVersion.V2;

import java.io.InputStream;

import org.junit.Test;
import org.openjdk.jmc.flightrecorder.configuration.events.EventConfiguration;
import org.openjdk.jmc.flightrecorder.configuration.events.IEventConfiguration;
import org.openjdk.jmc.flightrecorder.configuration.events.SchemaVersion;
import org.openjdk.jmc.flightrecorder.configuration.model.xml.XMLModel;

@SuppressWarnings("nls")
public class EventConfigurationTest {

	private IEventConfiguration loadConfig(String jfcName) throws Exception {
		try (InputStream in = EventConfigurationTest.class.getResourceAsStream(jfcName)) {
			XMLModel model = EventConfiguration.createModel(in);
			return new EventConfiguration(model);
		}
	}

	private void validateConfig(String jfcName, SchemaVersion version) throws Exception {
		try (InputStream in = EventConfigurationTest.class.getResourceAsStream(jfcName)) {
			EventConfiguration.validate(in, jfcName, version);
		}
	}

	@Test
	public void testLoadV1() throws Exception {
		loadConfig("continous_jfr_1_0.jfc");
	}

	@Test
	public void testLoadV2() throws Exception {
		loadConfig("continous_jfr_2_0.jfc");
	}

	@Test
	public void testValidateV1() throws Exception {
		validateConfig("continous_jfr_1_0.jfc", V1);
	}

	@Test
	public void testValidateV2() throws Exception {
		validateConfig("continous_jfr_2_0.jfc", V2);
	}
}
